@@ -18,11 +18,12 @@
 #'   \eqn{\mathbf{V}_{\mathrm{within}}}.
 #'
 #' @references
-#' Li, K. H., Raghunathan, T. E., & Rubin, D. B. (1991).
-#' Large-sample significance levels from multiply imputed data
-#' using moment-based statistics and an F reference distribution.
-#' *Journal of the American Statistical Association*, 86 (416), 1065–1073.
-#' \doi{10.1080/01621459.1991.10475152}
+#'   Li, K. H., Raghunathan, T. E., & Rubin, D. B. (1991).
+#'   Large-sample significance levels from multiply imputed data
+#'   using moment-based statistics and an F reference distribution.
+#'   *Journal of the American Statistical Association*,
+#'   86 (416), 1065–1073.
+#'   \doi{10.1080/01621459.1991.10475152}
 #'
 #' Rubin, D. B. (1987).
 #' *Multiple imputation for nonresponse in surveys*.
@@ -34,7 +35,5 @@
 #' @noRd
 .TotalAdj <- function(ariv,
                       within) {
-  return(
-    (1 + ariv) * within
-  )
+  (1 + ariv) * within
 }
