@@ -8,7 +8,7 @@
 #'   from the standard univariate normal distribution
 #'   \eqn{\mathbf{Z}}.
 #' @param svd Object.
-#'   Result of `svd()`.
+#'   Result of [svd()].
 #'
 #' @return Numeric matrix.
 #'
@@ -17,13 +17,11 @@
 #' @noRd
 .RandomGaussianSVD <- function(Z,
                                svd) {
-  return(
-    Z %*% svd$u %*% (
-      t(svd$v) * sqrt(
-        pmax(
-          svd$d,
-          0
-        )
+  Z %*% svd$u %*% (
+    t(svd$v) * sqrt(
+      pmax(
+        svd$d,
+        0
       )
     )
   )
